pub struct CoalescedRange {
pub page_start: u32,
pub page_end: u32,
pub byte_start: usize,
pub byte_length: usize,
}Expand description
A coalesced byte range covering one or more page indices.
Fields
page_start: u32page_end: u32byte_start: usizebyte_length: usizeTrait Implementations
Sourceimpl Clone for CoalescedRange
impl Clone for CoalescedRange
Sourcefn clone(&self) -> CoalescedRange
fn clone(&self) -> CoalescedRange
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CoalescedRange
impl Debug for CoalescedRange
Sourceimpl PartialEq for CoalescedRange
impl PartialEq for CoalescedRange
Sourcefn eq(&self, other: &CoalescedRange) -> bool
fn eq(&self, other: &CoalescedRange) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CoalescedRange
impl StructuralPartialEq for CoalescedRange